<div align="center">

<p align="center">
  <img src="https://raw.githubusercontent.com/BelloneLab/lisbet/main/docs/_static/logo_dark.png" alt="Logo" width="200">
</p><br>

[📚 Documentation](https://docs.lisbet.ai) |
[📦 Install](https://docs.lisbet.ai/en/latest/getting_started/installation.html) |
[🚀 Quickstart](https://docs.lisbet.ai/en/latest/getting_started/quickstart.html) |
[🪲 Reporting Issues](https://github.com/BelloneLab/lisbet/issues)

[![PyPI](https://img.shields.io/pypi/v/lisbet)](https://pypi.org/project/lisbet/)
[![Documentation Status](https://readthedocs.org/projects/lisbet/badge/?version=latest)](https://docs.lisbet.ai/en/latest/?badge=latest)
[![arXiv](https://img.shields.io/badge/arXiv-2311.04069-b31b1b.svg)](https://doi.org/10.48550/arXiv.2311.04069)

</div>

## About LISBET
LISBET (LISBET Is a Social BEhavior Transformer) is a machine learning model for social behavior discovery and classification.

See the [ROADMAP](ROADMAP.md) for an overview of the planned features and improvements.

> [!WARNING]
> LISBET is currently in beta and under active development.
> If you encounter any issues or bugs, please report them on our GitHub repository.
> We welcome feedback and contributions from the community.

## Installation
See the [installation guide](https://docs.lisbet.ai/en/latest/getting_started/installation.html) for a step-by-step guide on how to install LISBET.

## Citing LISBET
If you use LISBET in your research, please cite the following paper:

```bibtex
@misc{chindemi2023lisbet,
  title={LISBET: a machine learning model for the automatic segmentation of social behavior motifs},
  author={Giuseppe Chindemi and Benoit Girard and Camilla Bellone},
  year={2023},
  eprint={2311.04069},
  archivePrefix={arXiv},
  primaryClass={cs.CV}
}
```
